@@ -12,6 +12,7 @@ from torch.utils import model_zoo
 from .loggers import Logger
 from .settings import TEMP_DIR, ME_URL, CLIENTS_URL, MODELS_URL, JOBS_URL, SUBMISSIONS_URL, DATA_URL, BASE_URL
 from .settings import system_info
+from .model_zoo import *  # So loading models does not raise Attribute error
 
 # Load configuration parameters.
 # This includes a simple token authentication encoded in base64
@@ -118,6 +119,12 @@ def put(url, **kwargs):
     return handle_response(res)
 
 
+def patch(url, **kwargs):
+    logger.debug(f'Sending PATCH request to: {url}')
+    res = requests.patch(url, auth=get_auth(), **kwargs)
+    return handle_response(res)
+
+
 def delete(url, **kwargs):
     logger.debug(f'Sending DELETE request to: {url}')
     res = requests.delete(url, auth=get_auth(), **kwargs)
@@ -156,19 +163,14 @@ def get_jobs(**kwargs):
 
 
 def update_job_status(job, status, attach_log=False):
-    # Update status
-    job['status'] = status
-
-    # Pop file fields
-    job.pop('trained_model', None)
-    job.pop('log', None)
+    json = {'status': status}
 
     # Attach logfile if requested
     if attach_log:
         files = {'log': open(logger.file_path)}
-        return put(job['url'], data=job, files=files)
+        return patch(job['url'], data=json, files=files)
     else:
-        return put(job['url'], json=job)
+        return patch(job['url'], json=json)
 
 
 def update_job_next_round(job):
@@ -178,24 +180,16 @@ def update_job_next_round(job):
     :return:
     """
     logger.info('Updating to next round...')
-    # Avoid updating the files
-    job.pop('trained_model', None)
-    job.pop('log', None)
 
     # Step up in the next round
-    job['current_round'] += 1
-
-    return put(job['url'], json=job)
+    json = {'current_round': job['current_round'] + 1}
+    return patch(job['url'], json=json)
 
 
 def upload_trained_model(job, model):
     """Upload train model to job"""
-    # Remove previous logs and model files
-    job.pop('log', None)
-    job.pop('trained_model', None)
-
     files = {'trained_model': model_to_io_file(model)}
-    return put(job['url'], data=job, files=files)
+    return patch(job['url'], files=files)
 
 
 def get_submissions(job_url=None, current_round=None):
