@@ -25,6 +25,8 @@ class VAE(nn.Module):
     def __init__(self, in_dim, z_dim):
         super(VAE, self).__init__()
 
+        self.in_dim = in_dim
+
         # Encoder
         self.mu_enc = nn.Linear(in_dim, z_dim)
         self.logvar_enc = nn.Linear(in_dim, z_dim)
@@ -34,6 +36,9 @@ class VAE(nn.Module):
         self.logvar_dec = nn.Parameter(torch.ones(1, in_dim) * 0.5)
 
     def encode(self, x):
+        # Standardization
+        x = nn.BatchNorm1d(self.in_dim)(x)
+
         mu = self.mu_enc(x)
         std = self.logvar_enc(x).exp().pow(0.5)
         return Normal(loc=mu, scale=std)
